print("import: 'PIL'")
import PIL

print("import: 'PIL.Image'")
import PIL.Image

print("import: 'PIL._imaging'")
import PIL._imaging

print("import: 'PIL._imagingft'")
import PIL._imagingft

print("import: 'PIL._imagingmath'")
import PIL._imagingmath

print("import: 'PIL._imagingmorph'")
import PIL._imagingmorph

